<?php
namespace Teknisa\GER\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class SearchProdutoDemanda extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = "search_produtodemanda";
    protected $dataSourceManager;
    protected $environment;

    public function __construct($crudService, $parameterBag, $dataSourceManager, $environment) {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->environment = $environment;
    }

    public function searchProdutoDemanda(Request\Filter $request, Response $response) {
        try {
            $onDemandFilter = $request->getFilterCriteria();
            $conditions = $onDemandFilter->getConditions();

            if (end($conditions)['columnName'] !== 'CDPRODNIVANTE') {
                if (end($conditions)['operator'] == 'LIKE_ALL') {
                    $filter = end($conditions)['value'];
                    $newConditions = array(
                        array(
                            "columnName" => "FILTER",
                            "operator" => "=",
                            "value" => $filter
                        )
                    );
                    $onDemandFilter = new FilterCriteria('search_produtofilter', $newConditions);
                }
                else {
                    $onDemandFilter->addCondition('CDNVPRODUTO', '1');
                    $onDemandFilter->setDataSourceName($this->dataSourceName);
                }
            } else {
                $onDemandFilter->setDataSourceName($this->dataSourceName);
            }
            $onDemandFilter->addCondition("NRORG", $this->environment->getNrOrg());
            $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($onDemandFilter, array());
            $dataSource = $this->dataSourceManager->findBy($newFilterCriteria);
            $dataSet = self::montaDataSet($dataSource->getRows());
            $response->addDataSet(new DataSet('/searchProdutoDemanda', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }


    public function montaDataSet(array $dataSource) {
        $dataSet = array();

        foreach($dataSource as $data){
            array_push($dataSet, array(
                'CDARVPROD' => $data['CDARVPROD'],
                'CDPRODUTO' => $data['CDPRODUTO'],
                'NMPRODUTO' => $data['NMPRODUTO'],
                'SGUNIDADE' => $data['SGUNIDADE'],
                'CDNVPRODUTO' => $data['CDNVPRODUTO'],
                'CDPRODNIVANTE' => $data['CDPRODNIVANTE'],
                '_hasChild' => (boolean)$data['PAI']
            ));
        }
        return $dataSet;
    }
}